(* :Title: PhysicalConstantValues *)

(* :Author: Vladislav N. Larin *)

(* :Summary:
This package provides the mean values, standard uncertainties and relative
uncertainties of various commonly used physical constants.
*)

(* :Package Version: 2.1 *)

(* :Copyright: Copyright 2002-2010, Larin V.N. *)

(* :Context: MathematicaPackages`PhysicalConstantValues` *)

(* :History:
	Version 1.0 (100 constants) by V.N.Larin (SRCR IHEP), 24.04.2002
	Version 1.1 (112 constants) by V.N.Larin (SRCR IHEP), 24.09.2003
	Version 2.0 (112 constants) by V.N.Larin (SRCR IHEP), 25.02.2004
	Version 2.1 (113 constants) by V.N.Larin (SRCR IHEP), 25.06.2004
*)

(* :Keywords: *)

(* :Sources:
          P.J.Mohr, B.N.Taylor, CODATA Recommended Values of the Fundamental
          Physical Constants: 2002. http://physics.nist.gov/constants;
          S.Eidelman, K.G.Hayes, K.A.Olive, et al. Review of particle physics
          [Particle Data Group], Phys. Lett. B592 (2004) 1. http://pdg.lbl.gov
*)

(* :Warning: Redefines variables:  basicTable, standardNames *)

(* :Mathematica Version: 4.0, ... *)

(* :Limitation: This package has conflict with the 'StandardPhysicalConstants'
                package (by V.V.Ezhela and V.N.Larin). *)

(* :Discussion: *)

BeginPackage["MathematicaPackages`PhysicalConstantValues`"]

CODATA::usage =
"  P.J.Mohr, B.N.Taylor, CODATA recommended values of the fundamental
   physical constants: 2002;  http://physics.nist.gov/cuu/Constants"

PDG::usage =
"  P.J.Mohr and B.N.Taylor (NIST), 1.Physical Constants (Table 1.1).
  D.E.Groom (LBNL; revised 2001), M.A.Dobbs (LBNL; revised 2004)
  2.Astrophysical Constants (Table 2.1). In S.Eidelman, K.G.Hayes,
  K.A.Olive, et al. Review of particle physics [Particle Data Group],
  Phys. Lett. B592 (2004) 1; http://pdg.lbl.gov"

(*  1*)
accelerationOfGravity::usage =
"  Name: standard acceleration of gravity.
Source: CODATA Data (?CODATA).  Status: EXACT.
Uncertainty calculation method: NO.
Correlations: NO."
(*  2*)
ageOfUniverse::usage =
"  Name:  age of the universe.  
Source:  PDG Data (?PDG).   Status: INEXACT.
Uncertainty calculation method:  the standard error propagation
procedure for convertion of GYear (PDG data) to Seconds.
Correlations: UNKNOWN."
(*  3*)
ageOfUniverseInGYear::usage =
"  Name:  age of the universe in Gyear.  
Source:  PDG Data (?PDG).   Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(*  4*)
astronomicalUnit::usage =
"  Name: astronomical unit (mean Earth-Sun distance).
Source: PDG Data (?PDG). Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(*  5*)
atomicMassConstant::usage =
"  Name: atomic mass constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(*  6*)
avogadroConstant::usage =
"  Name: Avogadro constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(*  7*)
baryonDensityOfUniverse::usage =
"  Name: baryon density of the universe.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG data.
Correlations: UNKNOWN."
(*  8*)
bohrMagneton::usage =
"  Name: Bohr magneton.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(*  9*)
bohrMagnetonIneV::usage =
"  Name: Bohr magneton in eV/T.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 10*)
bohrRadius::usage =
"  Name: Bohr radius.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 11*)
boltzmannConstant::usage =
"  Name: Boltzmann constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 12*)
classicalElectronRadius::usage =
"  Name: classical electron radius.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 13*)
comptonWavelength::usage =
"  Name: Compton wavelength.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 14*)
comptonWavelengthReduced::usage =
"  Name: Compton wavelength over 2\[Pi].
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 15*)
conductanceQuantum::usage =
"  Name: conductance quantum.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 16*)
constantOfGravitation::usage =
"  Name: Newtonian constant of gravitation.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 17*)
conversionConstant::usage =
"  Name: Planck constant over 2\[Pi] times c in MeV fm.
Sources: PDG Data (?PDG), CODATA Data (?CODATA). Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 18*)
conversionConstantSquare::usage =
"  Name: conversion constant square.
Source: PDG Data (?PDG). Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 19*)
cosmicBackgroundTemperature::usage =
"  Name: present day CBR temperature.
Source: PDG Data (?PDG). Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 20*)
deuteronMagneticMoment::usage =
"  Name: deuteron magnetic moment.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 21*)
deuteronMass::usage =
"  Name: deuteron mass.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 22*)
earthMass::usage =
"  Name: Earth mass.  
Source: PDG Data (?PDG).  Status: INEXACT.  
Uncertainty calculation method: PDG Data.  
Correlations: UNKNOWN."
(* 23*)
earthRadius::usage =
"  Name: Earth mean equatorial radius.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 24*)
earthSchwarzschildRadius::usage =
"  Name: Schwarzschild radius of the Earth.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 25*)
electricConstant::usage =
"  Name: electric constant.
Source: CODATA Data (?CODATA).  Status: EXACT.
Uncertainty calculation method: NO.
Correlations: NO."
(* 26*)
electronChargeToMassQuotient::usage =
"  Name: electron charge to mass quotient.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 27*)
electronGFactor::usage =
"  Name: electron g-factor.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 28*)
electronMagneticMoment::usage =
"  Name: electron magnetic moment.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 29*)
electronMagneticMomentAnomaly::usage =
"  Name: electron magnetic moment anomaly.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 30*)
electronMass::usage =
"  Name: electron mass.
Source: CODATA Data (?CODATA). Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 31*)
electronMassInMeV::usage =
"  Name: electron mass energy equivalent in MeV.
Source: CODATA Data (?CODATA). Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 32*)
electronMuonMagneticMomentRatio::usage =
"  Name: electron-muon magnetic moment ratio.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 33*)
electronMuonMassRatio::usage =
"  Name: electron-muon mass ratio.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 34*)
elementaryCharge::usage =
"  Name: elementary charge.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 35*)
eVToKilogramRelationship::usage =
"  Name: electron volt-kilogram relationship.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 36*)
faradayConstant::usage =
"  Name: Faraday constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 37*)
fermiCouplingConstant::usage =
"  Name: Fermi coupling constant.
Source: PDG (?PDG) and CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: There are (CODATA Data)."
(* 38*)
fineStructureConstant::usage =
"  Name: fine-structure constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 39*)
galacticUnit::usage =
"  Name: solar distance from galactic center.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: the standard error propagation
procedure for convertion of kParsec (PDG data) to Meters.
Correlations: UNKNOWN."
(* 40*)
galacticUnitInParsec::usage =
"  Name: solar distance from galactic center in parsec.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 41*)
galaxyVelocityWithRespectToCBR::usage =
"  Name: Local group velocity with respect to CBR.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 42*)
hubbleConstant::usage =
"  Name: present day Hubble expansion rate (in SI).
Source: PDG Data (?PDG):  H0 = 100*h km s^-1 Mpc^-1;
here h=0.71+0.04/-0.03 (nonsymmetric uncertainty) is present
day normalized Hubble expansion rate.  Status: INEXACT.
Uncertainty calculation method:  we use symmetric uncertainty
(h=0.71+0.04/-0.04) and the standard error propagation procedure
for convertion of Mparsec (PDG data) to kMeters.
Correlations: UNKNOWN."
(* 43*)
icePoint::usage =
"  Name: ice point (standard temperature).
Source: http://www.digitaldutch.com/unitconverter/.  Status: INEXACT.
Uncertainty calculation method: UNKNOWN.
Correlations: UNKNOWN."
(* 44*)
impedanceOfVacuum::usage =
"  Name: characteristic impedance of vacuum.
Source: CODATA Data (?CODATA).  Status:  EXACT.  
Uncertainty calculation method:  NO. 
Correlations:  NO."
(* 45*)
inverseFineStructureConstant::usage =
"  Name: inverse fine-structure constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 46*)
jansky::usage =
"  Name: Jansky.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 47*)
localDiskDensity::usage =
"  Name: local disk density.
Source: PDG Data (?PDG). Status: INTERVAL (from MIN to MAX).
Uncertainty calculation method: (MAX-MIN)/2.
Correlations: UNKNOWN."
(* 48*)
localDiskDensityInGeV::usage =
"  Name: local disk density in GeV.
Source: PDG Data (?PDG). Status: INTERVAL (from MIN to MAX).
Uncertainty calculation method: (MAX-MIN)/2.
Correlations: UNKNOWN."
(* 49*)
localHaloDensity::usage =
"  Name: local halo density.
Source: PDG Data (?PDG). Status: INTERVAL (from MIN to MAX).
Uncertainty calculation method: (MAX-MIN)/2.
Correlations: UNKNOWN."
(* 50*)
localHaloDensityInGeV::usage =
"  Name: local halo density in GeV.
Source: PDG Data (?PDG). Status: INTERVAL (from MIN to MAX).
Uncertainty calculation method: (MAX-MIN)/2.
Correlations: UNKNOWN."
(* 51*)
magneticConstant::usage =
"  Name: magnetic constant.
Source: CODATA Data (?CODATA).  Status: EXACT.
Uncertainty calculation method: NO.
Correlations: NO."
(* 52*)
magneticFluxQuantum::usage =
"  Name: magnetic flux quantum.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 53*)
meanSiderealDay::usage =
"  Name: mean sidereal day (2005.0).
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 54*)
molarGasConstant::usage =
"  Name: molar gas constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 55*)
molarVolume::usage =
"  Name: molar volume of ideal gas (273.15 K, 101.325 kPa).  
Source:  CODATA Data (?CODATA).   Status:  INEXACT. 
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 56*)
muonComptonWavelength::usage =
"  Name: muon Compton wavelength.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 57*)
muonComptonWavelengthReduced::usage =
"  Name: muon Compton wavelength over 2\[Pi].
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 58*)
muonElectronMassRatio::usage =
"  Name: muon-electron mass ratio.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 59*)
muonGFactor::usage =
"  Name: muon g-factor.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 60*)
muonMagneticMoment::usage =
"  Name: muon magnetic moment.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 61*)
muonMagneticMomentAnomaly::usage =
"  Name: muon magnetic moment anomaly.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 62*)
muonMagneticMomentToBohrMagneton::usage =
"  Name: muon magnetic moment to Bohr magneton ratio.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 63*)
muonMass::usage =
"  Name: muon mass.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 64*)
muonMassInMeV::usage =
"  Name: muon mass energy equivalent in MeV.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 65*)
muonProtonMagneticMomentRatio::usage =
"  Name: muon-proton magnetic moment ratio. 
Source:  CODATA Data (?CODATA). Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 66*)
muonProtonMassRatio::usage =
"  Name: muon-proton mass ratio.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 67*)
neutronComptonWavelength::usage =
"  Name: neutron Compton wavelength.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 68*)
neutronMagneticMoment::usage =
"  Name: neutron magnetic moment.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 69*)
neutronMass::usage =
"  Name: neutron mass.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 70*)
normalizedBaryonDensity::usage =
"  Name: baryon-to-photon ratio.
Source:  PDG Data (?PDG).   Status:  INEXACT.
Uncertainty calculation method:  PDG Data.
Correlations: UNKNOWN."
(* 71*)
nuclearMagneton::usage =
"  Name: nuclear magneton.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 72*)
nuclearMagnetonIneV::usage =
"  Name: nuclear magneton in eV/T.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 73*)
parsec::usage =
"  Name: parsec (1 AU/1 arc sec).
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 74*)
planckConstant::usage =
"  Name: Planck constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 75*)
planckConstantInMeV::usage =
"  Name: Planck constant in eV s.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 76*)
planckConstantReduced::usage =
"  Name: Planck constant over 2\[Pi].
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 77*)
planckConstantReducedInMeV::usage =
"  Name: Planck constant over 2\[Pi] in eV s.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 78*)
planckLength::usage =
"  Name: Planck length.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 79*)
planckMass::usage =
"  Name: Planck mass.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 80*)
planckMassInGeV::usage =
"  Name: Planck mass energy equivalent in GeV.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 81*)
planckTime::usage =
"  Name: Planck time.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 82*)
pressurelessMatterDensity::usage =
"  Name: pressureless matter density of the universe.
Source: PDG Data (?PDG).   Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 83*)
protonChargeToMassQuotient::usage =
"  Name: proton charge to mass quotient.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 84*)
protonComptonWavelength::usage =
"  Name: proton Compton wavelength.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 85*)
protonMagneticMoment::usage =
"  Name: proton magnetic moment.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 86*)
protonMagneticMomentToBohrMagneton::usage =
"  Name:  proton magnetic moment to Bohr magneton ratio.   
Source:  CODATA Data (?CODATA).   Status:  INEXACT.  
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 87*)
protonMass::usage =
"  Name: proton mass.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 88*)
protonNeutronMassRatio::usage =
"  Name: proton-neutron mass ratio.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 89*)
rydbergConstant::usage =
"  Name: Rydberg constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 90*)
rydbergEnergy::usage =
"  Name: Rydberg constant times hc in eV.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 91*)
rydbergFrequency::usage =
"  Name: Rydberg constant times c in Hz.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 92*)
sackurTetrodeConstant::usage =
"  Name: Sackur-Tetrode constant (1 K, 101.325 kPa).
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(* 93*)
scaledCosmologicalConstant::usage =
"  Name: dark energy density.
Source: PDG Data (?PDG). Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 94*)
siderealYear::usage =
"  Name: sidereal year (fixed star to fixed star)(2005.0).
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(* 95*)
solarConstant::usage =
"  Name: mean total solar irradiance (TSI).
Source: PDG Data (?PDG); by formula:  solarConstant = 
solarLuminosity / (4\[Pi]*astronomicalUnit^2).  Status: INEXACT.
Uncertainty calculation method:  the standard error propagation
procedure.  Correlations: UNKNOWN."
(* 96*)
solarLuminosity::usage =
"  Name: solar luminosity.
Source: PDG Data (?PDG). Status: INEXACT.    
Uncertainty calculation method:  PDG Data.   
Correlations:  UNKNOWN."
(* 97*)
solarMass::usage =
"  Name: solar mass. 
Source: PDG Data (?PDG).  Status: INEXACT.  
Uncertainty calculation method: PDG Data.   
Correlations: UNKNOWN."
(* 98*)
solarRadius::usage =
"  Name: solar equatorial radius.
Source: PDG Data (?PDG). Status: INEXACT.
Uncertainty calculation method:  PDG Data (No).  
Correlations:  UNKNOWN."
(* 99*)
solarSchwarzschildRadius::usage =
"  Name: Schwarzschild radius of the Sun.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data (No).
Correlations: UNKNOWN."
(*100*)
solarVelocityAroundGalaxyCenter::usage =
"  Name: solar velocity around center of Galaxy.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(*101*)
solarVelocityWithRespectToCBR::usage =
"  Name: solar velocity with respect to CBR.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(*102*)
speedOfLightInVacuum::usage =
"  Name: speed of light in vacuum.
Source: CODATA Data (?CODATA).  Status: EXACT.
Uncertainty calculation method: NO.
Correlations: NO."
(*103*)
speedOfSound::usage =
"  Name: speed of sound.
Source: G.Wong, J.Acoust.Soc.Am. 79, 1359 (1986).
This is quoted by 'Units and Fundamental Constants
in Physics and Chemistry'. Subvolume a. Ed. by
J.Bortfeldt and B.Kramer. Springer-Verlag (1991).
Status: INEXACT.
Uncertainty calculation method: see source.
Correlations: UNKNOWN."
(*104*)
stefanBoltzmannConstant::usage =
"  Name: Stefan-Boltzmann constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(*105*)
strongCouplingConstant::usage =
"  Name: strong coupling constant.
Source: PDG Data (?PDG). Status: INEXACT.   
Uncertainty calculation method:  PDG Data.   
Correlations:  UNKNOWN."
(*106*)
tauMass::usage =
"  Name: tau mass.
Source: CODATA Data (?CODATA). Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(*107*)
thomsonCrossSection::usage =
"  Name: Thomson cross section.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(*108*)
tropicalYear::usage =
"  Name: tropical year (equinox to equinox)(2005.0).
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data (No).
Correlations: UNKNOWN."
(*109*)
wavelengthOfeVOverc0Particle::usage =
"  Name: wavelength of 1 eV/c particle.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(*110*)
wBosonMass::usage =
"  Name: W(+-) boson mass.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."
(*111*)
weakMixingAngle::usage =
"  Name: weak mixing angle.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: NO (CODATA Data)."
(*112*)
wienDisplacementLawConstant::usage =
"  Name: Wien displacement law constant.
Source: CODATA Data (?CODATA).  Status: INEXACT.
Uncertainty calculation method: CODATA Data.
Correlations: There are (CODATA Data)."
(*113*)
zBosonMass::usage =
"  Name: Z(0) boson mass.
Source: PDG Data (?PDG).  Status: INEXACT.
Uncertainty calculation method: PDG Data.
Correlations: UNKNOWN."

Access::usage =
"  Access[basicTable,constant_name] returns list of the constant values:
{meanvalue, uncertainty, relativeuncertainty}; {value, 0, 0} for unestimated
constants and {value, Exact, Exact}, if constant is exact."

ValueSyntax::usage =
"  ValueSyntax[basicTable[[i]]]  is syntax analyser of the value_string
(basicTable[[i,4]]) and the unit_string (basicTable[[i,5]]) for constant
pointed; returns number values: {value, uncert, relative_uncert}."

Presentation::usage =
"  Presentation[] presents full constants table in tabular form.
  Presentation[cname] ('cname' is package name of constant) presents
standard name of constant and its value in tabular form."

(* ======================================================================== *)
Unprotect[Access, ValueSyntax, CV, Presentation, basicTable, standardNames,
          Mole,mbarn,fMeter,kMeter,cMeter,Meter,kParsec,Gram,kGram,Joule,
          Weber,Kelvin,Ampere,Coulomb,eV,MeV,GeV,Volt,Tesla,Watt,Hertz,GYear,
          \[Theta],MS];

Begin["`Private`"]


 (*         =======================        *)
 (*         ACCESS to CONSTANT DATA        *) 
 (*         =======================        *)
 (*   From 'Manager_my.m' (1.3/26.06.03)   *)
 (*   Corrected Access from 'Manager_my.m'
                          (1.3/20.08.03)   *)
 (*   Corrected Access for PCV package
      specially (24.09.03)
      nast=SymbolName[name] ??? (19.02/04) *)
 
 Access[baslis:{___List},name_]:=

   Module[ {bcl=baslis, nast=SymbolName[name], dim, val,
            (* only for SPC: *) (* gbt=Global`basicTable, *)
            slv,magc},
           dim = First[Dimensions[bcl]];
           val = Table["Exact",{i,3}]; (* for ouput:
                                          {value,uncertainty,rel_uncert.} *)

(* EXACT CONSTANTS *)

           magc = 4 Pi 10^-7 Volt Second / Ampere / Meter;
(* only for SPC: *) (* slv  = ToExpression[gbt[[First[Flatten[Position[
                                     gbt, "speedOfLightInVacuum"]]], 4]]]; *)
           slv = ToExpression[StringReplace[bcl[[First[Flatten[Position[bcl,
                                       "speedOfLightInVacuum"]]],4]]," "->""]];
           Do[ If[ nast==bcl[[i,2]], 
(* 1 *)           (If[ nast=="accelerationOfGravity",
                       val[[1]]=ToExpression[StringReplace[bcl[[i,4]]," "->""]]*
                                Meter Second^-2;
                       Goto[ret] ];
(* 2 *)            If[ nast=="electricConstant",
                       val[[1]]=1/(magc*(slv Meter/Second)^2) /.
                                  Ampere -> Coulomb Second^-1;
                       Goto[ret] ];
(* 3 *)            If[ nast=="impedanceOfVacuum",
                       val[[1]]=magc*slv Meter/Second;
                       Goto[ret] ];
(* 4 *)            If[ nast=="magneticConstant", 
                       val[[1]] = magc;
                       Goto[ret] ];
(* 5 *)            If[ nast=="speedOfLightInVacuum",
                       val[[1]]=ToExpression[StringReplace[bcl[[i,4]]," "->""]]*
                                Meter Second^-1;
                       Goto[ret] ];

                           val=ValueSyntax[bcl[[i]]];  Goto[ret]),
                                        Continue[] ],  {i,1,dim}];

               Print[" Access: ",nast,"  is absent in the input table"];
               Return[];

Label[ret];    Return[val]   ]


(*                ====================                   *)
(*                ValueSyntax - module                   *)
(*                ====================                   *)

 ValueSyntax[subl_List]:=

      Module[ {sl=subl,val,sl5,leng,dash,leps,rips,tims,s1,s2,pw,pw1,
               pnts,pnt1=0,pnt2, str1,str2,nprec,j},
              val = Table[0,{i,3}];  (* ouput: {value,uncertainty,rel_uncert.} *)
              If[ Dimensions[sl[[4]]] != {}, sl[[4]]=First[sl[[4]]] ];
(*              If[ Dimensions[sl[[4]]][[1]] > 1, sl[[4]]=First[sl[[4]]] ]; *)
(*              If[ Dimensions[Dimensions[sl[[4]]]][[1]] > 1, *)
(*                  sl[[4]]=First[sl[[4]]][[1]] ]; *)
              sl5 = ToExpression[
                    StringReplace[sl[[5]],
                               {"mol" -> "Mole",   "mbarn" -> "mbarn",
                                "fm"  -> "fMeter", "km"    -> "kMeter",
                                "cm"  -> "cMeter", "m"     -> "Meter",
                                "s"   -> "Second", "kg"    -> "kGram",
                                "g"   -> "Gram",   "pc"    -> "Parsec",
                                "N"   -> "Newton", "J"     -> "Joule",
                                "Wb"  -> "Weber",  "K"     -> "Kelvin",
                                "A"   -> "Ampere", "C"     -> "Coulomb",
                                "eV"  -> "eV",     "V"     -> "Volt",
                                "T"   -> "Tesla",  "W"     -> "Watt",
                                "Hz"  -> "Hertz",  "Gyr"   -> "GYear"}]];
              If[ sl[[5]]==" "||sl[[5]]=="", sl5=1 ];
              sl[[4]] = StringReplace[sl[[4]], " " -> ""];       
              leng = StringLength[sl[[4]]];

(* "EXACT" FORMAT (temporary) *)

      If[ StringMatchQ[sl[[4]],"*(*)*"] == True, Goto[interval] ];

              nprec = leng;
              If[ StringMatchQ[sl[[4]],"*.*"] == True, nprec=nprec-1 ];
              If[ StringPosition[sl[[4]],"\[Times]"] != {},
                  nprec = StringPosition[sl[[4]],"\[Times]"][[1,1]] - 2];
              val[[1]] = SetPrecision[ToExpression[sl[[4]]], nprec] * sl5;
              Goto[ret];

(* "INTERVAL" FORMAT *)

Label[interval];   If[ StringTake[sl[[4]],{1}] != "(", Goto[inexact] ];
                       dash = StringPosition[sl[[4]],"-"][[1,1]];
                       rips = StringPosition[sl[[4]],")"][[1,1]];
                       tims = 
                   If[ First[Dimensions[StringPosition[sl[[4]],"\[Times]"]]]==0,
                       0,  StringPosition[sl[[4]],"\[Times]"][[1,1]]  ];
                   str1 = StringTake[sl[[4]],{2,dash-1}];
                   leng1 = StringLength[str1];
                   str2 = StringTake[sl[[4]],{dash+1,rips-1}];
                   leng2 = StringLength[str2];
                   If[ StringMatchQ[sl[[4]],"*.*"] == False, 
                   nprec = Dimensions[IntegerDigits[IntegerPart[
                           (ToExpression[str1]+ToExpression[str2])/2 ]]][[1]],
                   nprec = Max[leng1,leng2]-1;  If[StringTake[str1,{1}]=="0",
                   nprec = nprec - 1; If[leng1>leng2, nprec = nprec - 1] ] ];

If[ StringTake[str1,{1}]=="0" && leng1 > leng2,
    If[ OddQ[ToExpression[StringTake[str1,{leng1}]]]==True,
             nprec = nprec+1 ],
                   If[ (EvenQ[ToExpression[StringTake[str1,{leng1}]]]==True &&
                         OddQ[ToExpression[StringTake[str2,{leng2}]]]==True)||
                       ( OddQ[ToExpression[StringTake[str1,{leng1}]]]==True &&
                        EvenQ[ToExpression[StringTake[str2,{leng2}]]]==True),
                        nprec = nprec+1 ]  ];
(* Print[" str1 = ",str1," str2 = ",str2," dash = ",dash," nprec = ",nprec]; *)
                   s1 = SetPrecision[ToExpression[str1], nprec];
                   s2 = SetPrecision[ToExpression[str2], nprec];
                   pw = If[ tims==0, 1,
                            ToExpression[StringTake[sl[[4]],{tims+1,leng}]] ];
             val[[1]] = (s1+s2)/2 * pw * sl5;
             val[[2]] = (s2-s1)/2 * pw * sl5;
             val[[3]] = SetPrecision[val[[2]]/val[[1]], 2];
             Goto[ret];

(* "INEXACT" FORMAT *)

Label[inexact];        leps = StringPosition[sl[[4]],"("][[1,1]];
                       rips = StringPosition[sl[[4]],")"][[1,1]];
                       pnts = StringPosition[sl[[4]],"."];

                       pnt2 = First[Dimensions[pnts]];
                       If[ pnt2==2 || pnt2==0, pnts=0, pnt1=pnts[[1,1]];
                                                       pnts=leps-pnt1-1 ];
                       tims = 0;
                       If[ StringPosition[sl[[4]],"\[Times]"] != {},
                       tims = StringPosition[sl[[4]],"\[Times]"][[1,1]] ];

                   j = 0;
                   nprec = leps-1;
                   If[ StringTake[sl[[4]],{1}]=="-", nprec-=1; j+=1];
                   If[ pnt1 != 0 || pnt2==2, nprec-=1 ];
Label[precis];    
                   j += 1;
                   If[ StringTake[sl[[4]],{j}]=="0", nprec-=1; Goto[precis] ];
                   If[ StringTake[sl[[4]],{j}]==".", Goto[precis] ];
                   s1 = SetPrecision[
                        ToExpression[StringTake[sl[[4]],{1,leps-1}]], nprec];

                   nprec = rips-leps-1;
                   str2 = StringTake[sl[[4]],{leps+1,rips-1}];
                   If[ StringPosition[str2,"."] != {}, nprec=nprec-1 ];
                   s2 = SetPrecision[ToExpression[str2], nprec];
      If[ tims==0, pw = 1,
                   pw = ToExpression[StringTake[sl[[4]],{tims+1,leng}]] ];
                   pw1= 10.^-pnts;
             val[[1]] = s1 * pw * sl5;
             val[[2]] = SetPrecision[s2*pw1*pw, nprec] * sl5;
             val[[3]] = If[ val[[1]]=!=0.,SetPrecision[Abs[val[[2]]/val[[1]]],2],
                                      "",SetPrecision[Abs[val[[2]]/val[[1]]],2] ];
Label[ret];  
                Return[val]     ]

(*      --------------------------------------------------         *)

(* ================= The special presentation of constant values ===================== *)


   Presentation[cn___] :=
(* ----------------------- *)
      Module[ {i, bt3, strval, dim},
              If[ cn === Null,
                  Print["                     ",
                         StyleForm["    Physical Constant Table   ",
                                   FontSize->14, FontSlant->"Italic",
                                   FontWeight->"Bold", FontFamily->"Helvetica",
                                   FontColor->RGBColor[0,0.5,0.5]
                                   ]];
                   Print[StyleForm[TableForm[basicTable,TableSpacing->{1,0.6}],
                                   FontWeight -> "Bold"]];    Return[],

                   i = Flatten[Position[ToExpression[basicTable[[All,2]]],cn]];
                   If[i=={}, Print[StyleForm[cn,FontSize->12,FontSlant->"Italic"],
                                       "  is absent in the database!"]; Goto[ret],
                             i = First[i];
                             bt3 = basicTable[[i,3]];
                             strval = If[ StringQ[bt3], bt3 <> If[
                                              Dimensions[basicTable[[i,4]]]=={},
                                              " = "<>basicTable[[i,4]],
                                              " = "<>basicTable[[i,4]][[2]] ]<>
                                              " "<>basicTable[[i,5]],
                                        RowBox[Append[Part[Part[bt3, 1], 1],
                                        " = "<>basicTable[[i,4]]<>" "<>
                                        basicTable[[i,5]]]]//DisplayForm ];
                             If[ bt3==="msd", strval=StringDrop[strval,-2] ];
(*  12.05.2004
                             strval = basicTable[[i,3]] <> If[
                                              Dimensions[basicTable[[i,4]]]=={},
                                              " = "<>basicTable[[i,4]],
                                              " = "<>basicTable[[i,4]][[2]] ]<>
                                              " "<>basicTable[[i,5]];
*)
                            Print[StyleForm[standardNames[[i]]<>": ",
                                  FontSize->11,
                                  FontSlant->"Italic",
                                  FontWeight->"Bold",
                                  FontFamily->"Helvetica",
                                  FontColor->RGBColor[0.9,0,0]],"  ",
                                  StyleForm[strval,
                                            FontSize->11,
                                            FontSlant->"Italic",
                                            FontWeight->"Bold",
                                            FontFamily->"Helvetica"
(*                                            ,FontColor->RGBColor[0.9,0,0] *)
                                            ] ];
                  Print[StyleForm[TableForm[cn, TableAlignments -> {Center},
                                  TableDirections -> Row,
                  TableHeadings -> {{StyleForm["Value", FontWeight -> "Bold",
                                     FontSize->11,
                                     FontColor->RGBColor[0,0,0.90]],
                  StyleForm["Uncertainty", FontWeight -> "Bold",
                                     FontSize->11,
                                     FontColor->RGBColor[0,0,0.90]],
                  StyleForm["Relative uncert.", FontWeight -> "Bold",
                                     FontSize->11,
                                     FontColor->RGBColor[0,0,0.90]]}, None}],
                                     FontSize->11,
                                     FontSlant->"Italic",
                                     FontWeight -> "Bold"] ] ] ];
Label[ret];
            Return[cn]; ]

(* ===================== The main table of physical constants ======================= *)

 basicTable = 
 
{{1, "accelerationOfGravity", "g", "9.806 65", "m \!\(s\^\(-2\)\)"}, 
 {2, "ageOfUniverse", "\!\(t\_O\)", "4.32(6)\[Times]\!\(10\^17\)", "s"}, 
 {3, "ageOfUniverseInGYear", "\!\(t\_\(O,GY\)\)", "13.7(2)", "Gyr"}, 
 {4, "astronomicalUnit", "au", "149 597 870 660(20)", "m"}, 
 {5, "atomicMassConstant", "\!\(m\_u\)", 
  "1.660 538 86(28)\[Times]\!\(10\^\(-27\)\)", "kg"}, 
 {6, "avogadroConstant", "\!\(N\_A\)", 
  "6.022 1415(10)\[Times]\!\(10\^\(23\)\)", "\!\(mol\^\(-1\)\)"}, 
 {7, "baryonDensityOfUniverse", "\!\(\[CapitalOmega]\_B\)\!\(h\_0\%2\)", 
  "0.0224(9)", ""}, {8, "bohrMagneton", "\!\(\[Mu]\_B\)", 
  "927.400 949(80)\[Times]\!\(10\^\(-26\)\)", "J \!\(T\^\(-1\)\)"}, 
 {9, "bohrMagnetonIneV", "\!\(\[Mu]\_\(B,eV\)\)", 
  "5.788 381 804(39)\[Times]\!\(10\^\(-5\)\)", "eV \!\(T\^\(-1\)\)"}, 
 {10, "bohrRadius", "\!\(a\_\[Infinity]\)", 
  "0.529 177 2108(18)\[Times]\!\(10\^\(-10\)\)", "m"}, 
 {11, "boltzmannConstant", "k", "1.380 6505(24)\[Times]\!\(10\^\(-23\)\)", 
  "J \!\(K\^\(-1\)\)"}, {12, "classicalElectronRadius", "\!\(r\_e\)", 
  "2.817 940 325(28)\[Times]\!\(10\^\(-15\)\)", "m"}, 
 {13, "comptonWavelength", "\!\(\[Lambda]\_C\)", 
  "2.426 310 238(16)\[Times]\!\(10\^\(-12\)\)", "m"}, 
 {14, "comptonWavelengthReduced", "\!\(\[Lambda]\_C\)/2\[Pi]", 
  "386.159 2678(26)\[Times]\!\(10\^\(-15\)\)", "m"}, 
 {15, "conductanceQuantum", "\!\(G\_0\)", 
  "7.748 091 733(26)\[Times]\!\(10\^\(-5\)\)", "A \!\(V\^\(-1\)\)"}, 
 {16, "constantOfGravitation", "G", "6.6742(10)\[Times]\!\(10\^\(-11\)\)", 
  "\!\(m\^3\) \!\(kg\^\(-1\)\) \!\(s\^\(-2\)\)"}, 
 {17, "conversionConstant", "\!\(\[HBar]c\_0\)", "197.326 968(17)", 
  "MeV fm"}, {18, "conversionConstantSquare", 
  "(\!\(\[HBar]c\_0\)\!\(\()\^2\)\)", "0.389 379 323(67)", 
  "\!\(GeV\^2\) mbarn"}, {19, "cosmicBackgroundTemperature", "\!\(T\_O\)", 
  "2.725(1)", "K"}, {20, "deuteronMagneticMoment", "\!\(\[Mu]\_d\)", 
  "0.433 073 482(38)\[Times]\!\(10\^\(-26\)\)", "J \!\(T\^\(-1\)\)"}, 
 {21, "deuteronMass", "\!\(m\_d\)", 
  "3.343 583 35(57)\[Times]\!\(10\^\(-27\)\)", "kg"}, 
 {22, "earthMass", "\!\(\(M\_\[CirclePlus]\)\)", 
  "5.9723(9)\[Times]\!\(10\^24\)", "kg"}, {23, "earthRadius", 
  "\!\(\(R\_\[CirclePlus]\)\)", "6.378 140\[Times]\!\(10\^6\)", "m"}, 
 {24, "earthSchwarzschildRadius", "2\!\(GM\_\[CirclePlus]\)/\!\(c\_0\%2\)", 
  "8.870 056 22\[Times]\!\(10\^\(-3\)\)", "m"}, 
 {25, "electricConstant", "\!\(\[CurlyEpsilon]\_O\)", 
  "8.854 187 817\[Ellipsis]\[Times]\!\(10\^\(-12\)\)", 
  "C \!\(V\^\(-1\)\) \!\(m\^\(-1\)\)"}, {26, "electronChargeToMassQuotient", 
  "e/\!\(m\_e\)", "-1.758 820 12(15)\[Times]\!\(10\^\(11\)\)", 
  "C \!\(kg\^\(-1\)\)"}, {27, "electronGFactor", "\!\(g\_e\)", 
  "-2.002 319 304 3718(75)", " "}, {28, "electronMagneticMoment", 
  "\!\(\[Mu]\_e\)", "-928.476 412(80)\[Times]\!\(10\^\(-26\)\)", 
  "J \!\(T\^\(-1\)\)"}, {29, "electronMagneticMomentAnomaly", "\!\(a\_e\)", 
  "1.159 652 1859(38)\[Times]\!\(10\^\(-3\)\)", " "}, 
 {30, "electronMass", "\!\(m\_e\)", 
  "9.109 3826(16)\[Times]\!\(10\^\(-31\)\)", "kg"}, 
 {31, "electronMassInMeV", "\!\(m\_e\)\!\(c\_0\%2\)", "0.510 998 918(44)", 
  "MeV"}, {32, "electronMuonMagneticMomentRatio", 
  "\!\(\[Mu]\_e\)/\!\(\[Mu]\_\[Mu]\)", "206.766 9894(54)", ""}, 
 {33, "electronMuonMassRatio", "\!\(m\_e\)/\!\(m\_\[Mu]\)", 
  "4.836 331 67(13)\[Times]\!\(10\^\(-3\)\)", " "}, 
 {34, "elementaryCharge", "e", "1.602 176 53(14)\[Times]\!\(10\^\(-19\)\)", 
  "C"}, {35, "eVToKilogramRelationship", "(1eV)/\!\(c\_0\%2\)", 
  "1.782 661 81(15)\[Times]\!\(10\^\(-36\)\)", "kg"}, 
 {36, "faradayConstant", "F", "96 485.3383(83)", "C \!\(mol\^\(-1\)\)"}, 
 {37, "fermiCouplingConstant", "\!\(G\_F\)/(\!\(\[HBar]c\_0\)\!\(\()\^3\)\)", 
  "1.166 37(1)\[Times]\!\(10\^\(-5\)\)", "\!\(GeV\^\(-2\)\)"}, 
 {38, "fineStructureConstant", "\[Alpha]", 
  "7.297 352 568(24)\[Times]\!\(10\^\(-3\)\)", " "}, 
 {39, "galacticUnit", "\!\(R\_o\)", "2.47(15)\[Times]\!\(10\^20\)", "m"}, 
 {40, "galacticUnitInParsec", "\!\(R\_\(o,pc\)\)", "8.0(5)", "kpc"}, 
 {41, "galaxyVelocityWithRespectToCBR", "\!\(v\_LG\)", 
  "6.27(22)\[Times]\!\(10\^5\)", "m \!\(s\^\(-1\)\)"}, 
 {42, "hubbleConstant", "\!\(H\_0\)", "2.3(1)\[Times]\!\(10\^\(-18\)\)", 
  "\!\(s\^\(-1\)\)"}, {43, "icePoint", "\!\(T\_IceP\)", "273.15", "K"}, 
 {44, "impedanceOfVacuum", "\!\(Z\_O\)", "376.730 313 461\[Ellipsis]", 
  "V \!\(A\^\(-1\)\)"}, {45, "inverseFineStructureConstant", 
  "\!\(\[Alpha]\^\(-1\)\)", "137.035 999 11(46)", " "}, 
 {46, "jansky", "Jy", "1.\[Times]\!\(10\^\(-26\)\)", 
  "W \!\(m\^\(-2\)\) \!\(Hz\^\(-1\)\)"}, {47, "localDiskDensity", 
  "\!\(\[Rho]\_disk\)", "(3-12)\[Times]\!\(10\^\(-24\)\)", 
  "g \!\(cm\^\(-3\)\)"}, {48, "localDiskDensityInGeV", 
  "\!\(\[Rho]\_\(disk\)\)\!\(c\_0\%2\)", "(2-7)", "GeV \!\(cm\^\(-3\)\)"}, 
 {49, "localHaloDensity", "\!\(\[Rho]\_halo\)", 
  "(2-13)\[Times]\!\(10\^\(-25\)\)", "g \!\(cm\^\(-3\)\)"}, 
 {50, "localHaloDensityInGeV", "\!\(\[Rho]\_\(halo\)\)\!\(c\_0\%2\)", 
  "(0.1-0.7)", "GeV \!\(cm\^\(-3\)\)"}, {51, "magneticConstant", 
  "\!\(\[Mu]\_O\)", {{"4 \[Pi] \[Times] \!\(10\^\(-7\)\) ="}, 
   {"12.566 370 614\[Ellipsis]\[Times]\!\(10\^\(-7\)\)"}}, 
  "N \!\(A\^\(-2\)\)"}, {52, "magneticFluxQuantum", "\!\(\[CapitalPhi]\_O\)", 
  "2.067 833 72(18)\[Times]\!\(10\^\(-15\)\)", "Wb"}, 
 {53, "meanSiderealDay", "msd", {"86 164.090 53", 
   "\!\(23\^h\) \!\(56\^m\) \!\(04\^s\).09053"}, "s"}, 
 {54, "molarGasConstant", "R", "8.314 472(15)", 
  "J \!\(K\^\(-1\)\) \!\(mol\^\(-1\)\)"}, {55, "molarVolume", "\!\(V\_m\)", 
  "22.413 996(39)\[Times]\!\(10\^\(-3\)\)", "\!\(m\^3\) \!\(mol\^\(-1\)\)"}, 
 {56, "muonComptonWavelength", "\!\(\[Lambda]\_\(C, \[Mu]\)\)", 
  "11.734 441 05(30)\[Times]\!\(10\^\(-15\)\)", "m"}, 
 {57, "muonComptonWavelengthReduced", "\!\(\[Lambda]\_\(C, \[Mu]\)\)/2\[Pi]", 
  "1.867 594 298(47)\[Times]\!\(10\^\(-15\)\)", "m"}, 
 {58, "muonElectronMassRatio", "\!\(m\_\[Mu]\)/\!\(m\_e\)", 
  "206.768 2838(54)", " "}, {59, "muonGFactor", "\!\(g\_\[Mu]\)", 
  "-2.002 331 8396(12)", " "}, {60, "muonMagneticMoment", 
  "\!\(\[Mu]\_\[Mu]\)", "-4.490 447 99(40)\[Times]\!\(10\^\(-26\)\)", 
  "J \!\(T\^\(-1\)\)"}, {61, "muonMagneticMomentAnomaly", "\!\(a\_\[Mu]\)", 
  "1.165 919 81(62)\[Times]\!\(10\^\(-3\)\)", " "}, 
 {62, "muonMagneticMomentToBohrMagneton", 
  "\!\(\[Mu]\_\[Mu]\)/\!\(\[Mu]\_B\)", 
  "-4.841 970 45(13)\[Times]\!\(10\^\(-3\)\)", " "}, 
 {63, "muonMass", "\!\(m\_\[Mu]\)", 
  "1.883 531 40(33)\[Times]\!\(10\^\(-28\)\)", "kg"}, 
 {64, "muonMassInMeV", "\!\(m\_\[Mu]\)\!\(c\_0\%2\)", "105.658 3692(94)", 
  "MeV"}, {65, "muonProtonMagneticMomentRatio", 
  "\!\(\[Mu]\_\[Mu]\)/\!\(\[Mu]\_p\)", "-3.183 345 118(89)", " "}, 
 {66, "muonProtonMassRatio", "\!\(m\_\[Mu]\)/\!\(m\_p\)", 
  "0.112 609 5269(29)", ""}, {67, "neutronComptonWavelength", 
  "\!\(\[Lambda]\_\(C,n\)\)", "1.319 590 9067(88)\[Times]\!\(10\^\(-15\)\)", 
  "m"}, {68, "neutronMagneticMoment", "\!\(\[Mu]\_n\)", 
  "-0.966 236 45(24)\[Times]\!\(10\^\(-26\)\)", "J \!\(T\^\(-1\)\)"}, 
 {69, "neutronMass", "\!\(m\_n\)", 
  "1.674 927 28(29)\[Times]\!\(10\^\(-27\)\)", "kg"}, 
 {70, "normalizedBaryonDensity", "\!\(n\_B\)/\!\(n\_\[Gamma]\)", 
  "6.1(2)\[Times]\!\(10\^\(-10\)\)", ""}, {71, "nuclearMagneton", 
  "\!\(\[Mu]\_N\)", "5.050 783 43(43)\[Times]\!\(10\^\(-27\)\)", 
  "J \!\(T\^\(-1\)\)"}, {72, "nuclearMagnetonIneV", "\!\(\[Mu]\_\(N,eV\)\)", 
  "3.152 451 259(21)\[Times]\!\(10\^\(-8\)\)", "eV \!\(T\^\(-1\)\)"}, 
 {73, "parsec", "pc", "3.085 677 5807(4)\[Times]\!\(10\^16\)", "m"}, 
 {74, "planckConstant", "h", "6.626 0693(11)\[Times]\!\(10\^\(-34\)\)", 
  "J s"}, {75, "planckConstantInMeV", "\!\(h\_MeV\)", 
  "4.135 667 43(35)\[Times]\!\(10\^\(-21\)\)", "MeV s"}, 
 {76, "planckConstantReduced", "\[HBar]", 
  "1.054 571 68(18)\[Times]\!\(10\^\(-34\)\)", "J s"}, 
 {77, "planckConstantReducedInMeV", "\!\(\[HBar]\_MeV\)", 
  "6.582 119 15(56)\[Times]\!\(10\^\(-22\)\)", "MeV s"}, 
 {78, "planckLength", "\!\(l\_P\)", "1.616 24(12)\[Times]\!\(10\^\(-35\)\)", 
  "m"}, {79, "planckMass", "\!\(m\_P\)", 
  "2.176 45(16)\[Times]\!\(10\^\(-8\)\)", "kg"}, 
 {80, "planckMassInGeV", "\!\(m\_P\)\!\(c\_0\%2\)", 
  "1.22090(9)\[Times]\!\(10\^19\)", "GeV"}, {81, "planckTime", "\!\(t\_P\)", 
  "5.391 21(40)\[Times]\!\(10\^\(-44\)\)", "s"}, 
 {82, "pressurelessMatterDensity", "\!\(\[CapitalOmega]\_m\)", "0.27(4)", 
  ""}, {83, "protonChargeToMassQuotient", "e/\!\(m\_p\)", 
  "9.578 833 76(82)\[Times]\!\(10\^\(7\)\)", "C \!\(kg\^\(-1\)\)"}, 
 {84, "protonComptonWavelength", "\!\(\[Lambda]\_\(C,p\)\)", 
  "1.321 409 8555(88)\[Times]\!\(10\^\(-15\)\)", "m"}, 
 {85, "protonMagneticMoment", "\!\(\[Mu]\_p\)", 
  "1.410 606 71(12)\[Times]\!\(10\^\(-26\)\)", "J \!\(T\^\(-1\)\)"}, 
 {86, "protonMagneticMomentToBohrMagneton", "\!\(\[Mu]\_p\)/\!\(\[Mu]\_B\)", 
  "1.521 032 206(15)\[Times]\!\(10\^\(-3\)\)", " "}, 
 {87, "protonMass", "\!\(m\_p\)", 
  "1.672 621 71(29)\[Times]\!\(10\^\(-27\)\)", "kg"}, 
 {88, "protonNeutronMassRatio", "\!\(m\_p\)/\!\(m\_n\)", 
  "0.998 623 478 72(58)", ""}, {89, "rydbergConstant", 
  "\!\(R\_\[Infinity]\)", "10 973 731.568 525(73)", "\!\(m\^\(-1\)\)"}, 
 {90, "rydbergEnergy", "\!\(hc\_0\)\!\(R\_\[Infinity]\)", "13.605 6923(12)", 
  "eV"}, {91, "rydbergFrequency", "\!\(c\_0\)\!\(R\_\[Infinity]\)", 
  "3.289 841 960 360(22)\[Times]\!\(10\^\(15\)\)", "Hz"}, 
 {92, "sackurTetrodeConstant", "\!\(S\_0\)/R", "-1.164 8677(44)", " "}, 
 {93, "scaledCosmologicalConstant", 
  "\!\(\[CapitalOmega]\_\[CapitalLambda]\)", "0.73(4)", ""}, 
 {94, "siderealYear", "syr", "31 558 149.8", "s"}, 
 {95, "solarConstant", "\!\(\(S\_\[CircleDot]\)\)", 
  "1.3676(28)\[Times]\!\(10\^3\)", "W \!\(m\^\(-2\)\)"}, 
 {96, "solarLuminosity", "\!\(\(L\_\[CircleDot]\)\)", 
  "3.846(8)\[Times]\!\(10\^26\)", "W"}, {97, "solarMass", 
  "\!\(\(M\_\[CircleDot]\)\)", "1.988 44(30)\[Times]\!\(10\^30\)", "kg"}, 
 {98, "solarRadius", "\!\(\(R\_\[CircleDot]\)\)", "6.961\[Times]\!\(10\^8\)", 
  "m"}, {99, "solarSchwarzschildRadius", 
  "2\!\(\(GM\_\[CircleDot]\)\)/\!\(c\_0\%2\)", "2953.250 08", "m"}, 
 {100, "solarVelocityAroundGalaxyCenter", "\!\(\[CapitalTheta]\_0\)", 
  "2.20(20)\[Times]\!\(10\^5\)", "m \!\(s\^\(-1\)\)"}, 
 {101, "solarVelocityWithRespectToCBR", "\!\(\[CapitalTheta]\_CBR\)", 
  "3.68(2)\[Times]\!\(10\^5\)", "m \!\(s\^\(-1\)\)"}, 
 {102, "speedOfLightInVacuum", "\!\(c\_O\)", "299 792 458", 
  "m \!\(s\^\(-1\)\)"}, {103, "speedOfSound", "c", "331.29(7)", 
  "m \!\(s\^\(-1\)\)"}, {104, "stefanBoltzmannConstant", "\[Sigma]", 
  "5.670 400(40)\[Times]\!\(10\^\(-8\)\)", 
  "W \!\(m\^\(-2\)\) \!\(K\^\(-4\)\)"}, {105, "strongCouplingConstant", 
  "\!\(\[Alpha]\_s\)(\!\(m\_Z\))", "0.1187(20)", " "}, 
 {106, "tauMass", "\!\(m\_\[Tau]\)", "3.167 77(52)\[Times]\!\(10\^\(-27\)\)", 
  "kg"}, {107, "thomsonCrossSection", "\!\(\[Sigma]\_e\)", 
  "0.665 245 873(13)\[Times]\!\(10\^\(-28\)\)", "\!\(m\^2\)"}, 
 {108, "tropicalYear", "yr", "31 556 925.2", "s"}, 
 {109, "wavelengthOfeVOverc0Particle", "\!\(hc\_0\)/eV", 
  "1.239 841 91(11)\[Times]\!\(10\^\(-6\)\)", "m"}, 
 {110, "wBosonMass", "\!\(m\_W\)\!\(c\_0\%2\)", "80.425(38)", "GeV"}, 
 {111, "weakMixingAngle", DisplayForm[
   RowBox[{"\!\(sin\^2\)", OverHat[\[Theta]], "(\!\(M\_Z\))", "(", 
     OverBar[MS], ")"}]], "0.231 20(15)", " "}, 
 {112, "wienDisplacementLawConstant", "b", 
  "2.897 7685(51)\[Times]\!\(10\^\(-3\)\)", "m K"}, 
 {113, "zBosonMass", "\!\(m\_Z\)\!\(c\_0\%2\)", "91.1876(21)", "GeV"}}
 

 standardNames = 
 
{"standard acceleration of gravity", "age of the universe", 
 "age of the universe in Gyear", 
 "astronomical unit (mean \[CirclePlus]-\[CircleDot] distance)", 
 "atomic mass constant", "Avogadro constant", 
 "baryon density of the universe", "Bohr magneton", "Bohr magneton in eV/T", 
 "Bohr radius", "Boltzmann constant", "classical electron radius", 
 "Compton wavelength", "Compton wavelength over 2\[Pi]", 
 "conductance quantum", "Newtonian constant of gravitation", 
 "Planck constant over 2\[Pi] times c in MeV fm",
 "conversion constant square", "present day CBR temperature",
 "deuteron magnetic moment", "deuteron mass", 
 "Earth mass", "Earth mean equatorial radius", 
 "Schwarzschild radius of the Earth", "electric constant", 
 "electron charge to mass quotient", "electron g-factor", 
 "electron magnetic moment", "electron magnetic moment anomaly", 
 "electron mass", "electron mass energy equivalent in MeV", 
 "electron-muon magnetic moment ratio", "electron-muon mass ratio", 
 "elementary charge", "electron volt-kilogram relationship", 
 "Faraday constant", "Fermi coupling constant", "fine-structure constant", 
 "solar distance from galactic center", 
 "solar distance from galactic center in parsec", 
 "Local group velocity with respect to CBR", 
 "present day Hubble expansion rate in SI", 
 "ice point (standard temperature)", "characteristic impedance of vacuum", 
 "inverse fine-structure constant", "Jansky", "local disk density", 
 "local disk density in GeV", "local halo density", 
 "local halo density in GeV", "magnetic constant", "magnetic flux quantum", 
 "mean sidereal day (2005.0)", "molar gas constant", 
 "molar volume of ideal gas (273.15 K, 101.325 kPa)", 
 "muon Compton wavelength", "muon Compton wavelength over 2\[Pi]", 
 "muon-electron mass ratio", "muon g-factor", "muon magnetic moment", 
 "muon magnetic moment anomaly", 
 "muon magnetic moment to Bohr magneton ratio", "muon mass", 
 "muon mass energy equivalent in MeV", "muon-proton magnetic moment ratio", 
 "muon-proton mass ratio", "neutron Compton wavelength", 
 "neutron magnetic moment", "neutron mass", "baryon-to-photon ratio", 
 "nuclear magneton", "nuclear magneton in eV/T", "parsec (1 AU/1 arc sec)", 
 "Planck constant", "Planck constant in eV s", "Planck constant over 2\[Pi]", 
 "Planck constant over 2\[Pi] in eV s", "Planck length", "Planck mass", 
 "Planck mass energy equivalent in GeV", "Planck time", 
 "pressureless matter density of the universe", 
 "proton charge to mass quotient", "proton Compton wavelength", 
 "proton magnetic moment", "proton magnetic moment to Bohr magneton ratio", 
 "proton mass", "proton-neutron mass ratio", "Rydberg constant", 
 "Rydberg constant times hc in eV", "Rydberg constant times c in Hz", 
 "Sackur-Tetrode constant (1 K, 101.325 kPa)", "dark energy density", 
 "sidereal year (fixed star to fixed star)(2005.0)", 
 "mean total solar irradiance (TSI)", "solar luminosity", "solar mass", 
 "solar equatorial radius", "Schwarzschild radius of the Sun", 
 "solar velocity around center of Galaxy", 
 "solar velocity with respect to CBR", "speed of light in vacuum", 
 "speed of sound", "Stefan-Boltzmann constant", "strong coupling constant", 
 "tau mass", "Thomson cross section", 
 "tropical year (equinox to equinox)(2005.0)", 
 "wavelength of 1 eV/c particle", "\!\(W\^\[PlusMinus]\) boson mass", 
 "weak mixing angle", "Wien displacement law constant", 
 "\!\(Z\^0\) boson mass"}
 
 
(*         Specific symbols in names       *)
(*
      "Compton wavelength over 2\[Pi]"
      "Planck constant over 2\[Pi]"
      "\!\(W\^\[PlusMinus]\) bozon mass"
      "\!\(Z\^0\) bozon mass"
*)

(* === The assignment values to the package names of physical constants === *)

ToExpression[Table[basicTable[[i, 2]]<>"=.",{i,Length[basicTable]}]];
CV[c_] := Module[{}, c = Access[basicTable, c]; Return[]]
Map[CV[#] &, Symbol /@ basicTable[[All, 2]]];

End[]

SetAttributes[ Access,            ReadProtected];
SetAttributes[ ValueSyntax,       ReadProtected];
SetAttributes[ CV,                ReadProtected];
SetAttributes[ Presentation,      ReadProtected];
SetAttributes[ basicTable,        ReadProtected];
SetAttributes[ standardNames,     ReadProtected];

Protect[Access, ValueSyntax, CV, Presentation, basicTable, standardNames,
        Mole,mbarn,fMeter,kMeter,cMeter,Meter,kParsec,Gram,kGram,Joule,
        Weber,Kelvin,Ampere,Coulomb,eV,MeV,GeV,Volt,Tesla,Watt,Hertz,GYear,
        \[Theta],MS];

(* =============================== The HEAD =============================== *)
Print[" "]; Print[" "];

Print["       ",StyleForm["  'PhysicalConstantValues' Package   ",
                                 FontSize->20,
                                 FontSlant->"Plain",
                                 FontWeight->"Bold",
                                 FontFamily->"Times",
                                 FontColor->RGBColor[0,0,0.75]
]];

Print["                     ",StyleForm["  Version 2.1 (25.06.2004)",
                                 FontSize->16,
                                 FontSlant->"Italic",
                                 FontWeight->"Bold",
                                 FontFamily->"Times",
                                 FontColor->RGBColor[0,0,0.75]
]];

Print[" "]; Print[" "];

 (date = Date[];
Print[StyleForm["        DATE:  ",FontSize->14, FontWeight->"Bold",
                                                   FontFamily->"Helvetica"],
StyleForm[ToString[date[[3]]]<>".",FontSize->14, FontWeight->"Bold"],
StyleForm[ToString[date[[2]]]<>".",FontSize->14, FontWeight->"Bold"],
StyleForm[date[[1]],FontSize->14, FontWeight->"Bold"]];

Print[StyleForm["        TIME:   ",FontSize->14, FontWeight->"Bold",
                                                   FontFamily->"Helvetica"],
StyleForm[If[date[[4]]>9,ToString[date[[4]]]<>":",
                         "0"<>ToString[date[[4]]]<>":"],
                                          FontSize->14, FontWeight->"Bold"],
StyleForm[If[date[[5]]>9,date[[5]],
             "0"<>ToString[date[[5]]]],FontSize->14, FontWeight->"Bold"]];)

Print[" "]; Print[" "];

(* =========================== The end of HEAD ============================ *)

EndPackage[]
