(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28645,        828]*)
(*NotebookOutlinePosition[     29647,        862]*)
(*  CellTagsIndexPosition[     29517,        855]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["                 The \"PhysicalConstantValues 2.1\" Package", \
"Subsubtitle",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[TextData[{
  "This package is meant for an easy access to widely used physical,  \
astrophysical and physicochemical\nconstants, which are of interest to \
specialists in high energy physics, particle physics, astrophysics\nand \
cosmology. This package can be considered as an extention of the standard \
package\n",
  StyleBox["Miscellaneous`PhysicalConstants",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["`",
    FontVariations->{"CompatibilityType"->0}],
  " of the  ",
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["  ",
    FontSlant->"Italic"],
  "system, both by the number of constants\nand number of their numerical \
characteristics. The current version of the package database contains\n113 \
constants. The main sources of data included in the package database are\n\n\
",
  StyleBox["1)",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontVariations->{"CompatibilityType"->0}],
  "P.J.Mohr, B.N.Taylor,  ",
  StyleBox["CODATA Recommended  Values  of  the Fundamental Physical \
Constants:\n    2002.",
    FontSlant->"Italic"],
  "    http://physics.nist.gov/Constants.\n",
  StyleBox["2)",
    FontWeight->"Bold"],
  " S. Eidelman, K.G. Hayes, K.A. Olive, et al.   ",
  StyleBox["Review  of  particle  physics ",
    FontSlant->"Italic"],
  " [Particle Data Group], \n    Phys. Lett.  ",
  StyleBox["B592",
    FontWeight->"Bold"],
  " (2004) 1.   http://pdg.lbl.gov.\n\nThe more detailed description of the \
early package version (1.1), which does not have any fundamental\ndifferences \
from current version, can be found in the work by Larin V.N. ",
  StyleBox["The 'PhysicalConstantValues'  ",
    FontSlant->"Italic"],
  "\n",
  StyleBox["Package   for   ",
    FontSlant->"Italic"],
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["  System. ",
    FontSlant->"Italic"],
  "IHEP Preprint 2002-40.- Protvino, 2002 (in Russian).\nThe work can be \
found at  http://dbserv.ihep.su/~pubs/prep2002/ps/2002-40.pdf"
}], "Text",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["When located  in the ",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[" system  ",
    FontWeight->"Plain"],
  StyleBox["directory",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["Autoload,  ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["the package can be loaded\n as follows:",
    FontWeight->"Plain"]
}], "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(<< PhysicalConstantValues.m\)\)\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"       \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"  'PhysicalConstantValues' Package   \"\>",
            FontFamily->"Times",
            FontSize->20,
            FontWeight->"Bold",
            FontSlant->"Plain",
            FontColor->RGBColor[0, 0, 0.749996]],
          (
          StyleForm[ #, FontSize -> 20, FontSlant -> "Plain", FontWeight -> 
            "Bold", FontFamily -> "Times", FontColor -> RGBColor[ 
            0, 0, .75]]&)]}],
      SequenceForm[ "       ", 
        StyleForm[ 
        "  'PhysicalConstantValues' Package   ", FontSize -> 20, FontSlant -> 
          "Plain", FontWeight -> "Bold", FontFamily -> "Times", FontColor -> 
          RGBColor[ 0, 0, .75]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"                     \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"  Version 2.1 (25.06.2004)\"\>",
            FontFamily->"Times",
            FontSize->16,
            FontWeight->"Bold",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 0.749996]],
          (
          StyleForm[ #, FontSize -> 16, FontSlant -> "Italic", FontWeight -> 
            "Bold", FontFamily -> "Times", FontColor -> RGBColor[ 
            0, 0, .75]]&)]}],
      SequenceForm[ "                     ", 
        StyleForm[ 
        "  Version 2.1 (25.06.2004)", FontSize -> 16, FontSlant -> "Italic", 
          FontWeight -> "Bold", FontFamily -> "Times", FontColor -> RGBColor[ 
          0, 0, .75]]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"        DATE:  \"\>",
            FontFamily->"Helvetica",
            FontSize->14,
            FontWeight->"Bold"],
          (
          StyleForm[ #, FontSize -> 14, FontWeight -> "Bold", FontFamily -> 
            "Helvetica"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"7.\"\>",
            FontSize->14,
            FontWeight->"Bold"],
          (StyleForm[ #, FontSize -> 14, FontWeight -> "Bold"]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"6.\"\>",
            FontSize->14,
            FontWeight->"Bold"],
          (StyleForm[ #, FontSize -> 14, FontWeight -> "Bold"]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["2004",
            FontSize->14,
            FontWeight->"Bold"],
          (StyleForm[ #, FontSize -> 14, FontWeight -> "Bold"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "        DATE:  ", FontSize -> 14, FontWeight -> "Bold", FontFamily -> 
          "Helvetica"], 
        StyleForm[ "7.", FontSize -> 14, FontWeight -> "Bold"], 
        StyleForm[ "6.", FontSize -> 14, FontWeight -> "Bold"], 
        StyleForm[ 2004, FontSize -> 14, FontWeight -> "Bold"]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"        TIME:   \"\>",
            FontFamily->"Helvetica",
            FontSize->14,
            FontWeight->"Bold"],
          (
          StyleForm[ #, FontSize -> 14, FontWeight -> "Bold", FontFamily -> 
            "Helvetica"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"16:\"\>",
            FontSize->14,
            FontWeight->"Bold"],
          (StyleForm[ #, FontSize -> 14, FontWeight -> "Bold"]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["28",
            FontSize->14,
            FontWeight->"Bold"],
          (StyleForm[ #, FontSize -> 14, FontWeight -> "Bold"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "        TIME:   ", FontSize -> 14, FontWeight -> "Bold", FontFamily -> 
          "Helvetica"], 
        StyleForm[ "16:", FontSize -> 14, FontWeight -> "Bold"], 
        StyleForm[ 28, FontSize -> 14, FontWeight -> "Bold"]],
      Editable->False]], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "If  the  package is located  in  the  user  directory",
  StyleBox["  (e.g., ",
    FontWeight->"Plain"],
  StyleBox["d:\\PCV",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"],
  StyleBox[",  ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  "it can be loaded in the\nfollowing  way:"
}], "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\ \)\(<< d:\\PCV\\PhysicalConstantValues.m\)\)\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell["\<\
or with the help of the sequence of commands:\
\>", "Text",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(SetDirectory["\<d:\Pcv\>"];\)\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(\ \)\(<< PhysicalConstantValues.m\)\)\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "To obtain  the value of  the constant  wanted, you should enter its \
package name",
  StyleBox[" (\"",
    FontWeight->"Plain"],
  StyleBox["by hands",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["\" or  by\nclicking on a button in the ",
    FontWeight->"Plain"],
  StyleBox["palette  ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox["- see  below). ",
    FontWeight->"Plain"],
  "For example,  by typing  in  package name of  the ",
  StyleBox["proton  magnetic  moment",
    FontSlant->"Italic"],
  ",  we are getting its standard value:"
}], "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[" ",
        FontSlant->"Italic"], "protonMagneticMoment"}]], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \({\(1.4106067099999999260764`9*^-26\ Joule\)\/Tesla, \(1.2`2*^-33\ Joule\
\)\/Tesla, 8.5069778237419878`2*^-8}\)], "Output"]
}, Open  ]],

Cell["\<\
where the first element of the list shows the average value, while the second \
element - standard deviation and
the last one - a relative uncertainty. \
\>", "Text",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
In the same way you can obtain any element  of  the list,  representing   the \
value of the constant:\
\>", "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(First[protonMagneticMoment]\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(1.4106067099999999260764`9*^-26\ Joule\)\/Tesla\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(protonMagneticMoment[\([2]\)]\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(1.2`2*^-33\ Joule\)\/Tesla\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The values of so called  \"exact\" constants  (for example,  ",
  StyleBox["speed  of  light  in  vacuum",
    FontSlant->"Italic"],
  ")  are  presented  as:"
}], "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(speedOfLightInVacuum\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \({\(299792458\ Meter\)\/Second, "Exact", "Exact"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The values of  \"unestimated\" constants,  whose uncertainties  can not be \
found in the used sources \nof  data (for example, the ",
  StyleBox["Earth  mean  equatorial  radius",
    FontSlant->"Italic"],
  ") can be seen  as:"
}], "Subsubsection",
  CellMargins->{{0.375, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(earthRadius\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \({6.37814`7*^6\ Meter, 0, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "With the standard notebook front end,  the presentation  of  the constants \
 values  realised  with\nthe  help of  the  function ",
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["Presentation[ ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["constantname ",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  " is as follows:"
}], "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Presentation[localHaloDensity];\)\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"local halo density: \"\>",
            FontFamily->"Helvetica",
            FontSize->11,
            FontWeight->"Bold",
            FontSlant->"Italic",
            FontColor->RGBColor[0.900008, 0, 0]],
          (
          StyleForm[ #, FontSize -> 11, FontSlant -> "Italic", FontWeight -> 
            "Bold", FontFamily -> "Helvetica", FontColor -> 
            RGBColor[ .90000000000000002, 0, 0]]&)], 
        "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        TagBox[
          
          StyleBox["\<\"\\!\\(\[Rho]\\_halo\\) = \
(2-13)\[Times]\\!\\(10\\^\\(-25\\)\\) g \\!\\(cm\\^\\(-3\\)\\)\"\>",
            FontFamily->"Helvetica",
            FontSize->11,
            FontWeight->"Bold",
            FontSlant->"Italic"],
          (
          StyleForm[ #, FontSize -> 11, FontSlant -> "Italic", FontWeight -> 
            "Bold", FontFamily -> "Helvetica"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "local halo density: ", FontSize -> 11, FontSlant -> "Italic", 
          FontWeight -> "Bold", FontFamily -> "Helvetica", FontColor -> 
          RGBColor[ .90000000000000002, 0, 0]], "  ", 
        StyleForm[ 
        "\!\(\[Rho]\_halo\) = (2-13)\[Times]\!\(10\^\(-25\)\) g \
\!\(cm\^\(-3\)\)", FontSize -> 11, FontSlant -> "Italic", FontWeight -> 
          "Bold", FontFamily -> "Helvetica"]],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[
        InterpretationBox[GridBox[{
              {
                TagBox[
                  StyleBox["\<\"Value\"\>",
                    FontSize->11,
                    FontWeight->"Bold",
                    FontColor->RGBColor[0, 0, 0.900008]],
                  (
                  StyleForm[ #, FontWeight -> "Bold", FontSize -> 11, 
                    FontColor -> RGBColor[ 0, 0, .90000000000000002]]&)], 
                TagBox[
                  StyleBox["\<\"Uncertainty\"\>",
                    FontSize->11,
                    FontWeight->"Bold",
                    FontColor->RGBColor[0, 0, 0.900008]],
                  (
                  StyleForm[ #, FontWeight -> "Bold", FontSize -> 11, 
                    FontColor -> RGBColor[ 0, 0, .90000000000000002]]&)], 
                TagBox[
                  StyleBox["\<\"Relative uncert.\"\>",
                    FontSize->11,
                    FontWeight->"Bold",
                    FontColor->RGBColor[0, 0, 0.900008]],
                  (
                  StyleForm[ #, FontWeight -> "Bold", FontSize -> 11, 
                    FontColor -> RGBColor[ 0, 0, .90000000000000002]]&)]},
              {\(\(7.5`2.000000000000001*^-25\ Gram\)\/cMeter\^3\), \
\(\(5.5`1.865301426102544*^-25\ Gram\)\/cMeter\^3\), 
                "0.7333333333333315329`2.0000000000000004"}
              },
            RowSpacings->3,
            ColumnSpacings->1,
            RowAlignments->Baseline,
            ColumnAlignments->{Center}],
          TableForm[ {
            Times[ 7.5`2.000000000000001*^-25, 
              Power[ cMeter, -3], Gram], 
            Times[ 5.5`1.865301426102544*^-25, 
              Power[ cMeter, -3], Gram], 0.73`2.0000000000000004}, 
            TableAlignments -> {Center}, TableDirections -> Row, 
            TableHeadings -> {{
            StyleForm[ 
            "Value", FontWeight -> "Bold", FontSize -> 11, FontColor -> 
              RGBColor[ 0, 0, .90000000000000002]], 
            StyleForm[ 
            "Uncertainty", FontWeight -> "Bold", FontSize -> 11, FontColor -> 
              RGBColor[ 0, 0, .90000000000000002]], 
            StyleForm[ 
            "Relative uncert.", FontWeight -> "Bold", FontSize -> 11, 
              FontColor -> RGBColor[ 0, 0, .90000000000000002]]}, None}]],
        FontSize->11,
        FontWeight->"Bold",
        FontSlant->"Italic"],
      (StyleForm[ #, FontSize -> 11, FontSlant -> "Italic", FontWeight -> 
        "Bold"]&)]], "Print"]
}, Open  ]],

Cell[TextData[{
  "where the title contains a \"standard\" name of the constant (usually used \
in the corresponding source of data) and its value (as it is presented in the \
source and our data base). For the constants, whose values lie in the \
interval between  ",
  StyleBox["Min ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "and",
  StyleBox["  Max",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "  ",
  StyleBox["(Min - Max)",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ",  the average values and errors are calculated as follows: ",
  StyleBox["Value = (Min + Max)/2;",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "  ",
  StyleBox["Uncertainty = (Max - Min)/2.",
    FontWeight->"Bold",
    FontSlant->"Italic"]
}], "Text",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}]
}, Open  ]],

Cell[TextData[{
  "The function  ",
  StyleBox["Presentation[   ]",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "  with a null argument makes it possible  to get  the  full  table\nof  \
package names of  the constants  and their  values.\n"
}], "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
Additional information  about constants,  sources  of data and the programs \
can be obtained in
the following way:\
\>", "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?galacticUnit\)\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \("  Name: solar distance from galactic center. Source: PDG Data (?PDG).  \
Status: INEXACT. Uncertainty calculation method: the standard error \
propagation procedure for convertion of kParsec (PDG data) to Meters. \
Correlations: UNKNOWN."\)], "Print",
  CellTags->"Info3295616294-1672763"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?PDG\)\)], "Input"],

Cell[BoxData[
    \("  P.J.Mohr and B.N.Taylor (NIST), 1.Physical Constants (Table 1.1).   \
D.E.Groom (LBNL; revised 2001), M.A.Dobbs (LBNL; revised 2004)   \
2.Astrophysical Constants (Table 2.1). In S.Eidelman, K.G.Hayes,   K.A.Olive, \
et al. Review of particle physics [Particle Data Group],   Phys. Lett. B592 \
(2004) 1; http://pdg.lbl.gov"\)], "Print",
  CellTags->"Info3295616363-5397245"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Presentation\)\)], "Input",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}],

Cell[BoxData[
    \("  Presentation[] presents full constant table in tabular form.   \
Presentation[cname] (where 'cname' is package name of constant) presents \
standard name of constant and its value in tabular form."\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The package includes  the ",
  StyleBox["palette ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Plain"],
  "with the package names of the constants  as well as the command for \
loading the package from  the current  or system  directory  ",
  StyleBox["Autoload  ",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  "and two variants of  the  function  ",
  StyleBox["Presentation.  ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "To be able to use the palette, you should load the file  ",
  StyleBox["Palette.nb  ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "from  the directory  where this file is located. The usage of the palette  \
makes\nthe work with the package much easier in terms of inputting of  the \
names of  the constants  by clicking  on a button with the name of the \
constant  wanted. Some of  them are rather long."
}], "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
The table of the constants names in the current version of the package.\
\>", "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontSize->14,
  FontSlant->"Italic"],

Cell[BoxData[
    TagBox[
      StyleBox[
        TagBox[GridBox[{
              {"accelerationOfGravity", "ageOfUniverse"},
              {\(ageOfUniverseInGYear\^\[Copyright]\), \(astronomicalUnit\^\
\[Copyright]\)},
              {\(atomicMassConstant\^\[Copyright]\), "avogadroConstant"},
              {\(baryonDensityOfUniverse\^\[Copyright]\), \(bohrMagneton\^\
\[Copyright]\)},
              {\(bohrMagnetonIneV\^\[Copyright]\), "bohrRadius"},
              {"boltzmannConstant", "classicalElectronRadius"},
              {
                "comptonWavelength", \(comptonWavelengthReduced\^\[Copyright]\
\)},
              {"conductanceQuantum", "constantOfGravitation"},
              {\(conversionConstant\^\[Copyright]\), \
\(conversionConstantSquare\^\[Copyright]\)},
              {"cosmicBackgroundTemperature", "deuteronMagneticMoment"},
              {"deuteronMass", "earthMass"},
              {"earthRadius", \(earthSchwarzschildRadius\^\[Copyright]\)},
              {
                "electricConstant", \(electronChargeToMassQuotient\^\
\[Copyright]\)},
              {"electronGFactor", "electronMagneticMoment"},
              {\(electronMagneticMomentAnomaly\^\[Copyright]\), 
                "electronMass"},
              {\(electronMassInMeV\^\[Copyright]\), \
\(electronMuonMagneticMomentRatio\^\[Copyright]\)},
              {\(electronMuonMassRatio\^\[Copyright]\), "elementaryCharge"},
              {\(eVToKilogramRelationship\^\[Copyright]\), 
                "faradayConstant"},
              {\(fermiCouplingConstant\^\[Copyright]\), 
                "fineStructureConstant"},
              {"galacticUnit", \(galacticUnitInParsec\^\[Copyright]\)},
              {\(galaxyVelocityWithRespectToCBR\^\[Copyright]\), 
                "hubbleConstant"},
              {"icePoint", \(impedanceOfVacuum\^\[Copyright]\)},
              {\(inverseFineStructureConstant\^\[Copyright]\), \(jansky\^\
\[Copyright]\)},
              {\(localDiskDensity\^\[Copyright]\), \(localDiskDensityInGeV\^\
\[Copyright]\)},
              {\(localHaloDensity\^\[Copyright]\), \(localHaloDensityInGeV\^\
\[Copyright]\)},
              {"magneticConstant", "magneticFluxQuantum"},
              {\(meanSiderealDay\^\[Copyright]\), "molarGasConstant"},
              {"molarVolume", \(muonComptonWavelength\^\[Copyright]\)},
              {\(muonComptonWavelengthReduced\^\[Copyright]\), \
\(muonElectronMassRatio\^\[Copyright]\)},
              {"muonGFactor", "muonMagneticMoment"},
              {\(muonMagneticMomentAnomaly\^\[Copyright]\), \
\(muonMagneticMomentToBohrMagneton\^\[Copyright]\)},
              {"muonMass", \(muonMassInMeV\^\[Copyright]\)},
              {\(muonProtonMagneticMomentRatio\^\[Copyright]\), \
\(muonProtonMassRatio\^\[Copyright]\)},
              {"neutronComptonWavelength", "neutronMagneticMoment"},
              {"neutronMass", \(normalizedBaryonDensity\^\[Copyright]\)},
              {\(nuclearMagneton\^\[Copyright]\), \(nuclearMagnetonIneV\^\
\[Copyright]\)},
              {\(parsec\^\[Copyright]\), "planckConstant"},
              {\(planckConstantInMeV\^\[Copyright]\), 
                "planckConstantReduced"},
              {\(planckConstantReducedInMeV\^\[Copyright]\), \(planckLength\^\
\[Copyright]\)},
              {"planckMass", \(planckMassInGeV\^\[Copyright]\)},
              {\(planckTime\^\[Copyright]\), \(pressurelessMatterDensity\^\
\[Copyright]\)},
              {\(protonChargeToMassQuotient\^\[Copyright]\), 
                "protonComptonWavelength"},
              {
                "protonMagneticMoment", \
\(protonMagneticMomentToBohrMagneton\^\[Copyright]\)},
              {"protonMass", \(protonNeutronMassRatio\^\[Copyright]\)},
              {"rydbergConstant", "rydbergEnergy"},
              {\(rydbergFrequency\^\[Copyright]\), "sackurTetrodeConstant"},
              {\(scaledCosmologicalConstant\^\[Copyright]\), \(siderealYear\^\
\[Copyright]\)},
              {"solarConstant", "solarLuminosity"},
              {\(solarMass\^\[Copyright]\), "solarRadius"},
              {
                "solarSchwarzschildRadius", \(solarVelocityAroundGalaxyCenter\
\^\[Copyright]\)},
              {\(solarVelocityWithRespectToCBR\^\[Copyright]\), 
                "speedOfLightInVacuum"},
              {"speedOfSound", "stefanBoltzmannConstant"},
              {\(strongCouplingConstant\^\[Copyright]\), \(tauMass\^\
\[Copyright]\)},
              {"thomsonCrossSection", \(tropicalYear\^\[Copyright]\)},
              {\(wavelengthOfeVOverc0Particle\^\[Copyright]\), \(wBosonMass\^\
\[Copyright]\)},
              {
                "weakMixingAngle", \
\(wienDisplacementLawConstant\^\[Copyright]\)},
              {\(zBosonMass\^\[Copyright]\), "\<\"\"\>"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          Function[ BoxForm`e$, 
            TableForm[ BoxForm`e$, TableSpacing -> {1, 1}]]],
        FontFamily->"Courier",
        FontSize->10,
        Background->GrayLevel[0.949996]],
      (StyleForm[ #, FontSize -> 10, FontFamily -> "Courier", Background -> 
        GrayLevel[ .94999999999999996]]&)]], "Print",
  CellMargins->{{14.375, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  StyleBox["\[Copyright] ",
    FontVariations->{"CompatibilityType"->0}],
  " indicates the names of the constants which are not found in the standard \
package",
  StyleBox[" ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["PhysicalConstants",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["`",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\n(v",
    FontVariations->{"CompatibilityType"->0}],
  "ersion 1.4",
  StyleBox[").",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}}]
}, Open  ]],

Cell[TextData[{
  "The author asks to address all the remarks and proposals  on  the package \
to Larin V.N.\n",
  StyleBox["(larin@mx.ihep.su).   ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "He will also appreciate  any information  concerning  the usage\nof  the \
package presented."
}], "Subsubsection",
  CellMargins->{{Inherited, 32.625}, {Inherited, Inherited}},
  FontWeight->"Plain"]
}, Open  ]]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{746, 575},
WindowMargins->{{58, Automatic}, {199, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3295616294-1672763"->{
    Cell[19711, 609, 310, 5, 60, "Print",
      CellTags->"Info3295616294-1672763"]},
  "Info3295616363-5397245"->{
    Cell[20102, 622, 398, 6, 76, "Print",
      CellTags->"Info3295616363-5397245"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3295616294-1672763", 29290, 845},
  {"Info3295616363-5397245", 29406, 848}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 190, 4, 54, "Subsubtitle"],
Cell[1932, 57, 2174, 55, 318, "Text"],

Cell[CellGroupData[{
Cell[4131, 116, 556, 18, 60, "Subsubsection"],

Cell[CellGroupData[{
Cell[4712, 138, 136, 2, 28, "Input"],
Cell[4851, 142, 36, 1, 24, "Print"],
Cell[4890, 145, 36, 1, 27, "Print"],
Cell[4929, 148, 811, 19, 41, "Print"],
Cell[5743, 169, 820, 19, 34, "Print"],
Cell[6566, 190, 36, 1, 27, "Print"],
Cell[6605, 193, 36, 1, 27, "Print"],
Cell[6644, 196, 1307, 35, 33, "Print"],
Cell[7954, 233, 1036, 28, 33, "Print"],
Cell[8993, 263, 36, 1, 27, "Print"],
Cell[9032, 266, 36, 1, 27, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9117, 273, 459, 15, 71, "Subsubsection"],
Cell[9579, 290, 145, 2, 33, "Input"],
Cell[9727, 294, 131, 3, 39, "Text"],
Cell[9861, 299, 126, 2, 33, "Input"],
Cell[9990, 303, 136, 2, 33, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10163, 310, 702, 21, 92, "Subsubsection"],

Cell[CellGroupData[{
Cell[10890, 335, 174, 4, 33, "Input"],
Cell[11067, 341, 143, 2, 46, "Output"]
}, Open  ]],
Cell[11225, 346, 238, 5, 61, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11500, 356, 220, 5, 51, "Subsubsection"],

Cell[CellGroupData[{
Cell[11745, 365, 122, 2, 33, "Input"],
Cell[11870, 369, 83, 1, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11990, 375, 124, 2, 33, "Input"],
Cell[12117, 379, 62, 1, 46, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12228, 386, 284, 7, 71, "Subsubsection"],

Cell[CellGroupData[{
Cell[12537, 397, 115, 2, 33, "Input"],
Cell[12655, 401, 82, 1, 43, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12786, 408, 350, 8, 71, "Subsubsection"],

Cell[CellGroupData[{
Cell[13161, 420, 106, 2, 33, "Input"],
Cell[13270, 424, 61, 1, 33, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13380, 431, 560, 18, 72, "Subsubsection"],

Cell[CellGroupData[{
Cell[13965, 453, 130, 2, 33, "Input"],
Cell[14098, 457, 1466, 35, 34, "Print"],
Cell[15567, 494, 2534, 57, 83, "Print"]
}, Open  ]],
Cell[18116, 554, 827, 25, 104, "Text"]
}, Open  ]],
Cell[18958, 582, 355, 9, 92, "Subsubsection"],

Cell[CellGroupData[{
Cell[19338, 595, 233, 6, 71, "Subsubsection"],

Cell[CellGroupData[{
Cell[19596, 605, 112, 2, 33, "Input"],
Cell[19711, 609, 310, 5, 60, "Print",
  CellTags->"Info3295616294-1672763"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20058, 619, 41, 1, 33, "Input"],
Cell[20102, 622, 398, 6, 76, "Print",
  CellTags->"Info3295616363-5397245"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20537, 633, 112, 2, 33, "Input"],
Cell[20652, 637, 233, 3, 60, "Print"]
}, Open  ]]
}, Open  ]],
Cell[20912, 644, 1024, 26, 152, "Subsubsection"],

Cell[CellGroupData[{
Cell[21961, 674, 205, 5, 56, "Subsubsection"],
Cell[22169, 681, 5275, 106, 1280, "Print"],
Cell[27447, 789, 764, 23, 61, "Text"]
}, Open  ]],
Cell[28226, 815, 403, 10, 92, "Subsubsection"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

